import { effect, className, template } from 'solid-js/web';
import HighlightJS from 'highlight.js';
import { mergeProps, createMemo } from 'solid-js';

function escapeHtml(value) {
  return value.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#x27;");
}

const _tmpl$ = /*#__PURE__*/template(`<pre><code></code></pre>`, 4);

const Highlight = _props => {
  const props = mergeProps({
    autoDetect: true,
    ignoreIllegals: true,
    language: ""
  }, _props);
  const cannotDetectLanguage = !props.autoDetect && !props.language && !HighlightJS.getLanguage(props.children);
  const className$1 = cannotDetectLanguage ? "" : `hljs ${props.language}`;
  const getHighlightedCode = createMemo(() => {
    if (cannotDetectLanguage) {
      console.warn(`The language "${props.language}" you specified could not be found.`);
      return escapeHtml(props.children);
    }

    if (props.autoDetect) {
      const result = HighlightJS.highlightAuto(props.children);
      return result.value;
    } else {
      const result = HighlightJS.highlight(props.children, {
        language: props.language,
        ignoreIllegals: props.ignoreIllegals
      });
      return result.value;
    }
  });
  return (() => {
    const _el$ = _tmpl$.cloneNode(true),
          _el$2 = _el$.firstChild;

    effect(_p$ => {
      const _v$ = `${className$1} ${props.class || ""}`,
            _v$2 = getHighlightedCode();

      _v$ !== _p$._v$ && className(_el$2, _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && (_el$2.innerHTML = _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  })();
};

export { Highlight as default };
